@@ -17,10 +17,11 @@ from pysmi.parser import NullParser
 from pysmi.codegen import NullCodeGen
 from pysmi.compiler import MibCompiler
 
-inputMibs = ['BORROWED-MIB']
+inputMibs = ['MIKROTIK-MIB']
+
 
 httpBorrowers = [
-    ('mibs.pysnmp.com', 80, '/pysnmp/notexts/@mib@')
+    ('mibs.snmplabs.com', 80, '/pysnmp/notexts/@mib@')
 ]
 dstDirectory = '.pysnmp-mibs'
 
@@ -34,11 +35,9 @@ mibCompiler = MibCompiler(
 mibCompiler.addSearchers(PyFileSearcher(dstDirectory))
 
 # search for precompiled MIBs at Web sites
-mibCompiler.addBorrowers(
-    *[PyFileBorrower(HttpReader(*x)) for x in httpBorrowers]
-)
+mibCompiler.addBorrowers(*[PyFileBorrower(HttpReader('https://pysnmp.github.io/mibs/notexts/@mib@'))])
 
 # run MIB compilation
 results = mibCompiler.compile(*inputMibs)
 
-print('Results: %s' % ', '.join(['%s:%s' % (x, results[x]) for x in results]))
+print('Results: %s' % ', '.join([f'{x}:{results[x]}' for x in results]))
