@@ -16,7 +16,6 @@ Also, we do not check if target file already exists thus MIB
 compilation occurs on every invocation.
 """#
 from pysmi.reader import HttpReader
-from pysmi.reader import FtpReader
 from pysmi.searcher import StubSearcher
 from pysmi.writer import PyFileWriter
 from pysmi.parser import SmiStarParser
@@ -39,8 +38,7 @@ mibCompiler = MibCompiler(
 )
 
 # search for source MIBs at Web and FTP sites
-mibCompiler.addSources(*[HttpReader(*x) for x in httpSources])
-mibCompiler.addSources(*[FtpReader(*x) for x in ftpSources])
+mibCompiler.addSources(HttpReader('https://pysnmp.github.io/mibs/asn1/@mib@'))
 
 # never recompile MIBs with MACROs
 mibCompiler.addSearchers(StubSearcher(*PySnmpCodeGen.baseMibs))
@@ -48,4 +46,4 @@ mibCompiler.addSearchers(StubSearcher(*PySnmpCodeGen.baseMibs))
 # run non-recursive MIB compilation
 results = mibCompiler.compile(*inputMibs, **dict(noDeps=True))
 
-print('Results: %s' % ', '.join(['%s:%s' % (x, results[x]) for x in results]))
+print('Results: %s' % ', '.join([f'{x}:{results[x]}' for x in results]))
